% =============================================== %
% assembles a (6 x 6) block of the transformation
% matrix L
% =============================================== %

function L_loc = assemble_boundary_block(a, b, t, n)

% Input:    a: the vector a of the transformation
%           b: the vector b of the transformation
%           t: the tangent at the point p or an edge
%           n: the normal at the point p or the other edge
% 
% Output:   L_loc: the (6 x 6) block of the matrix L corresponding to p

    detA = a(1)*b(2) - a(2)*b(1);
    L_loc(1:6, 1:6) = eye(6);
    L_loc(2:3, 2:3) = [t(1)*b(2) - t(2)*b(1), t(2)*a(1) - t(1)*a(2);
                   n(1)*b(2) - n(2)*b(1), n(2)*a(1) - n(1)*a(2)]/detA;
    L_loc(4:6, 4:6) = [t(1)^2*b(2)^2 - 2*t(1)*t(2)*b(1)*b(2) + t(2)^2*b(1)^2,                   2*(-t(1)^2*a(2)*b(2) + t(1)*t(2)*(a(2)*b(1) + a(1)*b(2)) - t(2)^2*a(1)*b(1)),                       t(1)^2*a(2)^2 - 2*t(1)*t(2)*a(1)*a(2) + t(2)^2*a(1)^2; ...
                   n(1)*t(1)*b(2)^2 - (n(1)*t(2) + n(2)*t(1))*b(1)*b(2) + t(2)*n(2)*b(1)^2, -2*t(1)*n(1)*a(2)*b(2) + (n(1)*t(2) + n(2)*t(1))*(a(2)*b(1) + a(1)*b(2)) - 2*n(2)*t(2)*a(1)*b(1),   t(1)*n(1)*a(2)^2 - (n(1)*t(2) + n(2)*t(1))*a(1)*a(2) + n(2)*t(2)*a(1)^2; ...
                   n(1)^2*b(2)^2 - 2*n(1)*n(2)*b(1)*b(2) + n(2)^2*b(1)^2,                   2*(-n(1)^2*a(2)*b(2) + n(1)*n(2)*(a(2)*b(1) + a(1)*b(2)) - n(2)^2*a(1)*b(1)),                       n(1)^2*a(2)^2 - 2*n(1)*n(2)*a(1)*a(2) + n(2)^2*a(1)^2] ...
                   / detA^2;
end