% =============================================== %
% integrates a polynomial on the unit square
% with the tensor product Gauss quadrature
% of the order m.
% =============================================== %

function Q = integral_square_gauss(f, m)

% Input:    f, a function handle
%           m, the order or the quadrature

    ns = 1:m-1;
    a = (ns./(sqrt(4*ns.^2 - 1))).';
    A = spdiags([[a; 0], zeros(m, 1), [0; a]], -1:1, m, m);
    [V, D] = eig(full(A));
    
    lambdas = diag(D);
    ws = 2*(V(1, :).').^2;
    
    Q = 0;
    for i = 1:m
        for j = 1:m
          Q = Q + f([0.5*(1 + lambdas(i)); 0.5*(1 + lambdas(j))])*ws(i)*ws(j);
        end
    end
    Q = 0.25*Q;

end